/*
 * Copyright 2008 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 */


/*
 * Band.cpp
 *
 *  Created on: 2010/12/10
 *      Author: HARK Development Team
 */

#include <DimensionPromise/dimpro.hpp>
#include <Band.hpp>

using namespace NSDimensionPromise;

namespace NSHarkBinaural
{

NSDimensionPromise::Frequency Band::Freq() const
{
    if (this->bandInfo != 0)
    {
        return this->bandInfo->FreqOfBand(*this);
    }
    return Frequency(0.0); // error
}

BandInformation::BandInformation(NSDimensionPromise::Frequency fs, unsigned int ndft)
    : fs(fs), ndft(ndft)
{
    if (fs.ToHz() < 0)
    {
        this->fs = Frequency(0.0);
    }
}

Band BandInformation::CreateBand(int index) const
{
    if (0 <= index && index <= this->ndft / 2)
    {
        return Band(index, this);
    }
    return Band();
}

Band BandInformation::CreateBand(NSDimensionPromise::Frequency f) const
{
    if (Frequency::FromHz(0.0) <= f && f <= this->fs / 2.0)
    {
        return Band((f * (double)this->ndft / this->fs).X(), this);
    }
    return Band();
}

NSDimensionPromise::Frequency BandInformation::FreqOfBand(const Band& band) const
{
    if (0 <= band.Index() && band.Index() <= this->ndft / 2)
    {
        return (double)band.Index() * this->fs / (double)this->ndft;
    }
    return Frequency(0.0);
}

}
