/*
 * Copyright 2008 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 */


/*
 * LoggerInitializer.cpp
 *
 *  Created on: 2010/12/20
 *      Author: HARK Development Team
 */

#include <string>
#include <Node.h>
#include <Logger.hpp>
using namespace std;
using namespace FD;
using namespace NSHarkBinaural;

class LoggerInitializer;

DECLARE_NODE(LoggerInitializer);
/*Node
 *
 * @name LoggerInitializer
 * @category HARK:BINAURAL
 * @description Initialize the global logger
 *
 * @parameter_name LOGGER
 * @parameter_type string
 * @parameter_value global
 * @parameter_description The name of logger which you want to initialize.
 *
 * @parameter_name LOG_LEVEL
 * @parameter_type string
 * @parameter_value INFO
 * @parameter_list ALL:FINEST:FINER:FINE:CONFIG:INFO:WARNING:SEVERE:OFF
 * @parameter_description The logging level of global logger. [default: INFO]
 *
 END*/

static LogLevel StringToLevel(const string& level)
{
    if (level == "ALL")     return LogLevel(LogLevel::ALL);
    if (level == "FINEST")  return LogLevel(LogLevel::FINEST);
    if (level == "FINER")   return LogLevel(LogLevel::FINER);
    if (level == "FINE")    return LogLevel(LogLevel::FINE);
    if (level == "CONFIG")  return LogLevel(LogLevel::CONFIG);
    if (level == "INFO")    return LogLevel(LogLevel::INFO);
    if (level == "WARNING") return LogLevel(LogLevel::WARNING);
    if (level == "SEVERE")  return LogLevel(LogLevel::SEVERE);
    if (level == "OFF")     return LogLevel(LogLevel::OFF);
}

class LoggerInitializer: public Node
{
public:
    LoggerInitializer(string nodeName, ParameterSet params)
        : Node(nodeName, params)
    {
        string loggerName = object_cast<string>(parameters.get("LOGGER"));
        if (loggerName == "global")
        {
            loggerName = Logger::GLOBAL_LOGGER_NAME;
        }
        Logger& logger = Logger::GetLogger(loggerName);
        string logLevel = object_cast<string>(parameters.get("LOG_LEVEL"));
        logger.SetLevel(StringToLevel(logLevel));
    }

    virtual ~LoggerInitializer()
    {
    }

    virtual ObjectRef getOutput(int output_id, int count)
    {
    }
};
